@@ -9,7 +9,7 @@ require(fanovaGraph)
 fun <- function(x) {x[,1]*x[,2]*x[,3] + x[,4]*x[,5]*x[,6] + 
   0.7*x[,1]*x[,2]*x[,3]*x[,4]*x[,5]*x[,6]}
 
-g <- estimateGraph(fun, d=6, q.arg=list(min=-1,max=1), n.tot=20000, method="FixLO")
+g <- estimateGraph(fun, d=6, q.arg=list(min=-1,max=1), n.tot=20000, method="LiuOwen")
 
 ### plots for threshold decision:
 
